@@ -4,12 +4,12 @@
 
 /* Package information */
 #define PACKAGE           "task"
-#define VERSION           "2.1.2"
+#define VERSION           "2.2.0"
 #define PACKAGE_BUGREPORT "support@taskwarrior.org"
 #define PACKAGE_NAME      "task"
 #define PACKAGE_TARNAME   "task"
-#define PACKAGE_VERSION   "2.1.2"
-#define PACKAGE_STRING    "task 2.1.2"
+#define PACKAGE_VERSION   "2.2.0"
+#define PACKAGE_STRING    "task 2.2.0"
 
 /* Installation details */
 #define TASK_RCDIR "/usr/local/share/doc/task/rc"
@@ -17,11 +17,9 @@
 /* Localization */
 #define PACKAGE_LANGUAGE  1
 #define LANGUAGE_EN_US 1
-
-/*
-Override PACKAGE_LANGUAGE, then
-#define LANGUAGE_XX_YY 2
-*/
+#define LANGUAGE_ES_ES 2
+#define LANGUAGE_DE_DE 3
+#define LANGUAGE_FR_FR 4
 
 /* git information */
 #define HAVE_COMMIT
@@ -41,9 +39,6 @@ Override PACKAGE_LANGUAGE, then
 /* #undef SOLARIS */
 /* #undef UNKNOWN */
 
-/* Found the lua library */
-#define HAVE_LIBLUA
-
 /* Found the pthread library */
 /* #undef HAVE_LIBPTHREAD */
 
