@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 // taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2012, Paul Beckingham, Federico Hernandez.
+// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -97,7 +97,7 @@ static struct
   {  "_hastag_", 9,         'b',  0,      'l'},     // +tag  [Pseudo-op]
   {  "_notag_",  9,         'b',  0,      'l'},     // -tag  [Pseudo-op]
 
-//  {  "-",       15,         'u',  1,      'r' },    // Unary minus
+  {  "-",       15,         'u',  1,      'r' },    // Unary minus
   {  "*",       13,         'b',  1,      'l' },    // Multiplication
   {  "/",       13,         'b',  1,      'l' },    // Division
 //  {  "%",       13,         'b',  1,      'l' },    // Modulus
@@ -384,6 +384,10 @@ void A3::resolve_aliases ()
     std::vector <Arg>::iterator arg;
     for (arg = this->begin (); arg != this->end (); ++arg)
     {
+      // The -- operator stops alias expansion.
+      if (arg->_raw == "--")
+        break;
+
       std::map <std::string, std::string>::iterator match =
         context.aliases.find (arg->_raw);
 
@@ -408,6 +412,10 @@ void A3::resolve_aliases ()
         expanded.push_back (arg->_raw);
     }
 
+    // Copy any residual tokens.
+    for (; arg != this->end (); ++arg)
+      expanded.push_back (arg->_raw);
+
     // Only overwrite if something happened.
     if (something)
     {
@@ -694,9 +702,6 @@ const A3 A3::tokenize (const A3& input) const
   // List of operators for recognition.
   std::vector <std::string> operators = A3::operator_list ();
 
-  // Date format, for both parsing and rendering.
-  std::string date_format = context.config.get ("dateformat");
-
   // Nibble them apart.
   A3 output;
   Nibbler n (combined);
@@ -757,9 +762,9 @@ const A3 A3::tokenize (const A3& input) const
       // Must be higher than number.
       // Must be higher than operator.
       // Note that Nibbler::getDate does not read durations.
-      else if (n.getDate (date_format, t))
+      else if (is_date (n, s))
       {
-        output.push_back (Arg (Date (t).toString (date_format), Arg::type_date, Arg::cat_literal));
+        output.push_back (Arg (s, Arg::type_date, Arg::cat_literal));
         if (found_sequence)
           found_something_after_sequence = true;
       }
@@ -1569,6 +1574,23 @@ bool A3::is_dom (Nibbler& n, Arg& arg)
   return false;
 }
 
+////////////////////////////////////////////////////////////////////////////////
+bool A3::is_date (Nibbler& n, std::string& result)
+{
+  std::string date_format = context.config.get ("dateformat");
+  std::string::size_type start = n.save ();
+  time_t t;
+
+  if (n.getDate (date_format, t))
+  {
+    result = n.str ().substr (start, n.cursor () - start);
+    return true;
+  }
+
+  n.restore ();
+  return false;
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // A duration may only be followed by \0, ), +, -, *, / or ' '.
 //
