@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 // taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2012, Paul Beckingham, Federico Hernandez.
+// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -31,12 +31,10 @@
 #include <fstream>
 #include <sstream>
 #include <algorithm>
-#include <sys/types.h>
 #include <sys/stat.h>
 #include <inttypes.h>
 #include <unistd.h>
 #include <stdlib.h>
-#include <pwd.h>
 #include <Directory.h>
 #include <Date.h>
 #include <File.h>
@@ -113,7 +111,9 @@ std::string Config::_defaults =
   "dateformat.info=m/d/Y H:N:S                    # Preferred display date format for information\n"
   "dateformat.report=m/d/Y                        # Preferred display date format for reports\n"
   "dateformat.annotation=m/d/Y                    # Preferred display date format for annotations\n"
-  "weekstart=Sunday                               # Sunday or Monday only\n"
+  "weekstart="
+             STRING_DATE_SUNDAY_LONG
+                  "                               # Sunday or Monday only\n"
   "displayweeknumber=yes                          # Show week numbers on calendar\n"
   "due=7                                          # Task is considered due in 7 days\n"
   "\n"
@@ -211,6 +211,7 @@ std::string Config::_defaults =
   "color.blocking=white on color6                 # Color of blocking tasks\n"
   "#color.completed=on blue                       # Color of completed tasks\n"
   "#color.deleted=on blue                         # Color of deleted tasks\n"
+  "#color.uda.estimate=on green                   # Color of UDA\n"
 #else
   "color.header=yellow                            # Color of header messages\n"
   "color.footnote=yellow                          # Color of footnote messages\n"
@@ -265,12 +266,13 @@ std::string Config::_defaults =
   "color.blocking=black on bright white           # Color of blocking tasks\n"
   "#color.completed=on blue                       # Color of completed tasks\n"
   "#color.deleted=on blue                         # Color of deleted tasks\n"
+  "#color.uda.estimate=on green                   # Color of UDA\n"
 #endif
   "\n"
   "# Here is the rule precedence order, highest to lowest.\n"
   "# Note that these are just the color rule names, without the leading 'color.'\n"
   "#      and any trailing '.value'.\n"
-  "rule.precedence.color=due.today,active,blocking,blocked,overdue,due,scheduled,keyword.,project.,tag.,recurring,pri.,tagged,completed,deleted\n"
+  "rule.precedence.color=due.today,active,blocking,blocked,overdue,due,scheduled,keyword.,project.,tag.,uda.,recurring,pri.,tagged,completed,deleted\n"
   "\n"
   "# Shadow file support\n"
   "#shadow.file=/tmp/shadow.txt                   # Location of shadow file\n"
@@ -287,6 +289,7 @@ std::string Config::_defaults =
   "complete.all.tags=no                           # Include old tag names in '_ags' command\n"
   "list.all.projects=no                           # Include old project names in 'projects' command\n"
   "list.all.tags=no                               # Include old tag names in 'tags' command\n"
+  "print.empty.columns=no                         # Print columns which have no data for any task\n"
   "debug=no                                       # Display diagnostics\n"
   "extensions=off                                 # Extension system master switch\n"
   "fontunderline=yes                              # Uses underlines rather than -------\n"
@@ -300,22 +303,6 @@ std::string Config::_defaults =
 	"#merge.default.uri=user@host.xz:.task/         # URI for merge\n"
 	"#pull.default.uri=rsync://host.xz/task-backup/ # URI for pull\n"
 	"\n"
-  "# Import heuristics - alternate names for fields (comma-separated list of names)\n"
-  "#import.synonym.bg=?\n"
-  "#import.synonym.description=?\n"
-  "#import.synonym.due=?\n"
-  "#import.synonym.end=?\n"
-  "#import.synonym.entry=?\n"
-  "#import.synonym.fg=?\n"
-  "#import.synonym.id=?\n"
-  "#import.synonym.priority=?\n"
-  "#import.synonym.project=?\n"
-  "#import.synonym.recur=?\n"
-  "#import.synonym.start=?\n"
-  "#import.synonym.status=?\n"
-  "#import.synonym.tags=?\n"
-  "#import.synonym.uuid=?\n"
-  "\n"
   "# Aliases - alternate names for commands\n"
   "alias.rm=delete                                # Alias for the delete command\n"
   "alias.history=history.monthly                  # Prefer monthly over annual history reports\n"
@@ -327,99 +314,105 @@ std::string Config::_defaults =
   "\n"
   "report.long.description=Lists all pending tasks\n"
   "report.long.columns=id,project,priority,entry,start,due,recur,due.countdown,entry.age,depends,tags,description\n"
-  "report.long.labels=ID,Project,Pri,Added,Started,Due,Recur,Countdown,Age,Deps,Tags,Description\n"
+  "report.long.labels=ID,Proj,Pri,Added,Started,Due,Recur,Countdown,Age,Deps,Tags,Description\n"
   "report.long.sort=due+,priority-,project+\n"
   "report.long.filter=status:pending\n"
   "\n"
   "report.list.description=Lists all pending tasks\n"
   "report.list.columns=id,project,priority,due,start.active,entry.age,description\n"
-  "report.list.labels=ID,Project,Pri,Due,Active,Age,Description\n"
+  "report.list.labels=ID,Proj,Pri,Due,Active,Age,Description\n"
   "report.list.sort=due+,priority-,start-,project+\n"
   "report.list.filter=status:pending\n"
   "\n"
   "report.ls.description=Minimal listing of all pending tasks\n"
   "report.ls.columns=id,project,priority,description\n"
-  "report.ls.labels=ID,Project,Pri,Description\n"
+  "report.ls.labels=ID,Proj,Pri,Description\n"
   "report.ls.sort=priority-,project+\n"
   "report.ls.filter=status:pending\n"
   "\n"
   "report.minimal.description=Minimal listing of all pending tasks\n"
   "report.minimal.columns=id,project,description.truncated\n"
-  "report.minimal.labels=ID,Project,Description\n"
+  "report.minimal.labels=ID,Proj,Description\n"
   "report.minimal.sort=project+,description+\n"
   "report.minimal.filter=status:pending\n"
   "\n"
   "report.newest.description=Shows the newest tasks\n"
   "report.newest.columns=id,project,priority,due,start.active,entry.age,description\n"
-  "report.newest.labels=ID,Project,Pri,Due,Active,Age,Description\n"
+  "report.newest.labels=ID,Proj,Pri,Due,Active,Age,Description\n"
   "report.newest.sort=id-\n"
   "report.newest.filter=status:pending limit:10\n"
   "\n"
   "report.oldest.description=Shows the oldest tasks\n"
   "report.oldest.columns=id,project,priority,due,start.active,entry.age,description\n"
-  "report.oldest.labels=ID,Project,Pri,Due,Active,Age,Description\n"
+  "report.oldest.labels=ID,Proj,Pri,Due,Active,Age,Description\n"
   "report.oldest.sort=id+\n"
   "report.oldest.filter=status:pending limit:10\n"
   "\n"
   "report.overdue.description=Lists overdue tasks\n"
   "report.overdue.columns=id,project,priority,due,start.active,entry.age,description\n"
-  "report.overdue.labels=ID,Project,Pri,Due,Active,Age,Description\n"
+  "report.overdue.labels=ID,Proj,Pri,Due,Active,Age,Description\n"
   "report.overdue.sort=due+,priority-,start-,project+\n"
-  "report.overdue.filter=status:pending due.before:now\n"
+  "report.overdue.filter=status:pending +OVERDUE\n"
   "\n"
   "report.active.description=Lists active tasks\n"
   "report.active.columns=id,project,priority,due,start.active,entry.age,description\n"
-  "report.active.labels=ID,Project,Pri,Due,Active,Age,Description\n"
+  "report.active.labels=ID,Proj,Pri,Due,Active,Age,Description\n"
   "report.active.sort=due+,priority-,project+\n"
   "report.active.filter=status:pending start.any:\n"
   "\n"
   "report.completed.description=Lists completed tasks\n"
   "report.completed.columns=end,project,priority,entry.age,description,uuid\n"
-  "report.completed.labels=Complete,Project,Pri,Age,Description,UUID\n"
+  "report.completed.labels=Complete,Proj,Pri,Age,Description,UUID\n"
   "report.completed.sort=end+,priority-,project+\n"
   "report.completed.filter=status:completed\n"
   "\n"
   "report.recurring.description=Lists recurring tasks\n"
   "report.recurring.columns=id,project,priority,due,recur,start.active,entry.age,description\n"
-  "report.recurring.labels=ID,Project,Pri,Due,Recur,Active,Age,Description\n"
+  "report.recurring.labels=ID,Proj,Pri,Due,Recur,Active,Age,Description\n"
   "report.recurring.sort=due+,priority-,start-,project+\n"
   "report.recurring.filter=status:pending parent.any:\n"
   "\n"
   "report.waiting.description=Lists all waiting tasks\n"
   "report.waiting.columns=id,project,priority,wait,entry.age,description\n"
-  "report.waiting.labels=ID,Project,Pri,Wait,Age,Description\n"
+  "report.waiting.labels=ID,Proj,Pri,Wait,Age,Description\n"
   "report.waiting.sort=wait+,priority-,project+\n"
   "report.waiting.filter=status:waiting\n"
   "\n"
   "report.all.description=Lists all pending and completed tasks\n"
   "report.all.columns=id,status,project,priority,due,end,start.active,entry.age,description\n"
-  "report.all.labels=ID,Status,Project,Pri,Due,Completed,Active,Age,Description\n"
+  "report.all.labels=ID,Status,Proj,Pri,Due,Completed,Active,Age,Description\n"
   "report.all.sort=entry+\n"
   "report.all.filter=status.not:deleted\n"
   "\n"
   "report.next.description=Lists the most urgent tasks\n"
   "report.next.columns=id,project,priority,due,start.active,entry.age,urgency,description\n"
-  "report.next.filter=status:pending limit:page\n"
-  "report.next.labels=ID,Project,Pri,Due,A,Age,Urgency,Description\n"
+  "report.next.labels=ID,Proj,Pri,Due,A,Age,Urg,Description\n"
   "report.next.sort=urgency-,due+,priority-,start-,project+\n"
+  "report.next.filter=status:pending limit:page\n"
   "\n"
   "report.ready.description=Lists the most urgent tasks\n"
   "report.ready.columns=id,project,priority,due,start.active,entry.age,urgency,description\n"
-  "report.ready.filter=status:pending limit:page wait.none: '(scheduled.none: or scheduled.before:now )'\n"
-  "report.ready.labels=ID,Project,Pri,Due,A,Age,Urgency,Description\n"
+  "report.ready.labels=ID,Proj,Pri,Due,A,Age,Urg,Description\n"
   "report.ready.sort=urgency-,due+,priority-,start-,project+\n"
+  "report.ready.filter=status:pending limit:page wait.none: '(scheduled.none: or scheduled.before:now )'\n"
   "\n"
   "report.blocked.description=Lists all blocked tasks\n"
   "report.blocked.columns=id,depends,project,priority,due,start.active,entry.age,description\n"
-  "report.blocked.labels=ID,Deps,Project,Pri,Due,Active,Age,Description\n"
+  "report.blocked.labels=ID,Deps,Proj,Pri,Due,Active,Age,Description\n"
   "report.blocked.sort=due+,priority-,start-,project+\n"
-  "report.blocked.filter=status:pending depends.any:\n"
+  "report.blocked.filter=status:pending +BLOCKED\n"
   "\n"
   "report.unblocked.description=Lists all unblocked tasks\n"
   "report.unblocked.columns=id,depends,project,priority,due,start.active,entry.age,description\n"
-  "report.unblocked.labels=ID,Deps,Project,Pri,Due,Active,Age,Description\n"
+  "report.unblocked.labels=ID,Deps,Proj,Pri,Due,Active,Age,Description\n"
   "report.unblocked.sort=due+,priority-,start-,project+\n"
-  "report.unblocked.filter=status:pending depends.none:\n"
+  "report.unblocked.filter=status:pending -BLOCKED\n"
+  "\n"
+  "report.blocking.description=Lists all blocking tasks\n"
+  "report.blocking.columns=id,depends,project,priority,due,start.active,entry.age,description\n"
+  "report.blocking.labels=ID,Deps,Proj,Pri,Due,Active,Age,Description\n"
+  "report.blocking.sort=due+,priority-,start-,project+\n"
+  "report.blocking.filter=status:pending +BLOCKING\n"
   "\n";
 
 ////////////////////////////////////////////////////////////////////////////////
