@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 // taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2012, Paul Beckingham, Federico Hernandez.
+// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -31,7 +31,6 @@
 
 #include <vector>
 #include <string>
-#include <API.h>
 #include <cmake.h>
 
 // Hook class representing a single hook, which is just a three-way map.
@@ -68,9 +67,6 @@ private:
   bool validTaskEvent (const std::string&);
 
 private:
-#ifdef HAVE_LIBLUA
-  API _api;
-#endif
   std::vector <Hook> _all;           // All current hooks.
 
   std::vector <std::string> _validProgramEvents;
