@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 // taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2012, Paul Beckingham, Federico Hernandez.
+// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -54,12 +54,14 @@ public:
   bool readable () const;
   bool writable () const;
   bool executable () const;
+  bool rename (const std::string&);
 
   // Statics
   static std::string expand (const std::string&);
   static std::vector<std::string> glob (const std::string&);
 
 public:
+  std::string _original;
   std::string _data;
 };
 
