@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 // taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2012, Paul Beckingham, Federico Hernandez.
+// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -106,6 +106,7 @@ Task::Task ()
 , recalc_urgency (true)
 , is_blocked (false)
 , is_blocking (false)
+, annotation_count (0)
 {
 }
 
@@ -122,11 +123,12 @@ Task& Task::operator= (const Task& other)
   {
     std::map <std::string, std::string>::operator= (other);
 
-    id             = other.id;
-    urgency_value  = other.urgency_value;
-    recalc_urgency = other.recalc_urgency;
-    is_blocked     = other.is_blocked;
-    is_blocking    = other.is_blocking;
+    id               = other.id;
+    urgency_value    = other.urgency_value;
+    recalc_urgency   = other.recalc_urgency;
+    is_blocked       = other.is_blocked;
+    is_blocking      = other.is_blocking;
+    annotation_count = other.annotation_count;
   }
 
   return *this;
@@ -156,6 +158,7 @@ Task::Task (const std::string& input)
   recalc_urgency = true;
   is_blocked = false;
   is_blocking = false;
+  annotation_count = 0;
   parse (input);
 }
 
@@ -218,6 +221,14 @@ void Task::setStart ()
   recalc_urgency = true;
 }
 
+////////////////////////////////////////////////////////////////////////////////
+void Task::setModified ()
+{
+  char now[16];
+  sprintf (now, "%u", (unsigned int) time (NULL));
+  set ("modified", now);
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 bool Task::has (const std::string& name) const
 {
@@ -329,6 +340,60 @@ void Task::setStatus (Task::status status)
   recalc_urgency = true;
 }
 
+////////////////////////////////////////////////////////////////////////////////
+bool Task::is_due () const
+{
+  if (has ("due"))
+  {
+    Task::status status = getStatus ();
+
+    if (status != Task::completed &&
+        status != Task::deleted)
+    {
+      if (getDueState (get ("due")) == 1)
+        return true;
+    }
+  }
+
+  return false;
+}
+
+////////////////////////////////////////////////////////////////////////////////
+bool Task::is_duetoday () const
+{
+  if (has ("due"))
+  {
+    Task::status status = getStatus ();
+
+    if (status != Task::completed &&
+        status != Task::deleted)
+    {
+      if (getDueState (get ("due")) == 2)
+        return true;
+    }
+  }
+
+  return false;
+}
+
+////////////////////////////////////////////////////////////////////////////////
+bool Task::is_overdue () const
+{
+  if (has ("due"))
+  {
+    Task::status status = getStatus ();
+
+    if (status != Task::completed &&
+        status != Task::deleted)
+    {
+      if (getDueState (get ("due")) == 3)
+        return true;
+    }
+  }
+
+  return false;
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // Attempt an FF4 parse first, using Task::parse, and in the event of an error
 // try a legacy parse (F3, FF2).  Note that FF1 is no longer supported.
@@ -374,6 +439,9 @@ void Task::parse (const std::string& input)
               value[value.length () - 1] == 'm')
             value += 'o';
 
+          if (name.substr (0, 11) == "annotation_")
+            ++annotation_count;
+
           (*this)[name] = decode (json::decode (value));
         }
 
@@ -389,7 +457,7 @@ void Task::parse (const std::string& input)
       throw std::string (STRING_RECORD_NOT_FF4);
   }
 
-  catch (std::string& e)
+  catch (const std::string&)
   {
     legacyParse (copy);
   }
@@ -549,6 +617,7 @@ void Task::legacyParse (const std::string& line)
                   std::string name = pair.substr (0, colon);
                   std::string value = pair.substr (colon + 2, pair.length () - colon - 3);
                   set ("annotation_" + name, value);
+                  ++annotation_count;
                 }
               }
 
@@ -614,7 +683,6 @@ std::string Task::composeJSON (bool include_id /*= false*/) const
 
   // First the non-annotations.
   int attributes_written = 0;
-  int annotation_count = 0;
   Task::const_iterator i;
   for (i = this->begin (); i != this->end (); ++i)
   {
@@ -623,15 +691,9 @@ std::string Task::composeJSON (bool include_id /*= false*/) const
 
     Column* column = context.columns[i->first];
 
-    // Annotations are simply counted.
-    if (i->first.substr (0, 11) == "annotation_")
-    {
-      ++annotation_count;
-    }
-
     // Date fields are written as ISO 8601.
-    else if (column &&
-             column->type () == "date")
+    if (column &&
+        column->type () == "date")
     {
       Date d (i->second);
       out << "\""
@@ -714,6 +776,12 @@ std::string Task::composeJSON (bool include_id /*= false*/) const
   return out.str ();
 }
 
+////////////////////////////////////////////////////////////////////////////////
+bool Task::hasAnnotations () const
+{
+  return annotation_count ? true : false;
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 void Task::getAnnotations (std::map <std::string, std::string>& annotations) const
 {
@@ -735,6 +803,7 @@ void Task::setAnnotations (const std::map <std::string, std::string>& annotation
   for (ci = annotations.begin (); ci != annotations.end (); ++ci)
     this->insert (*ci);
 
+  annotation_count = annotations.size ();
   recalc_urgency = true;
 }
 
@@ -757,6 +826,7 @@ void Task::addAnnotation (const std::string& description)
   while (has (key));
 
   (*this)[key] = description;
+  ++annotation_count;
   recalc_urgency = true;
 }
 
@@ -768,7 +838,10 @@ void Task::removeAnnotations ()
   while (i != this->end ())
   {
     if (i->first.substr (0, 11) == "annotation_")
+    {
+      --annotation_count;
       this->erase (i++);
+    }
     else
       i++;
   }
@@ -885,6 +958,33 @@ int Task::getTagCount () const
 ////////////////////////////////////////////////////////////////////////////////
 bool Task::hasTag (const std::string& tag) const
 {
+  // Synthetic tags - dynamically generated, but do not occupy storage space.
+  if (tag == "BLOCKED")   return is_blocked;
+  if (tag == "UNBLOCKED") return !is_blocked;
+  if (tag == "BLOCKING")  return is_blocking;
+  if (tag == "DUE")       return is_due ();
+  if (tag == "DUETODAY")  return is_duetoday ();
+  if (tag == "TODAY")     return is_duetoday ();
+  if (tag == "OVERDUE")   return is_overdue ();
+  if (tag == "ACTIVE")    return has ("start");
+  if (tag == "SCHEDULED") return has ("scheduled");
+  if (tag == "CHILD")     return has ("parent");
+  if (tag == "UNTIL")     return has ("until");
+  if (tag == "WAITING")   return has ("wait");
+  if (tag == "ANNOTATED") return hasAnnotations ();
+
+/*
+  TODO YESTERDAY - due yesterday
+  TODO TOMORROW  - due tomorrow
+  TODO WEEK      - due this week
+  TODO MONTH     - due this month
+  TODO YEAR      - due this year
+  TODO READY     - is ready
+  TODO WAITING   - is waiting
+  TODO PARENT    - is a parent
+*/
+
+  // Concrete tags.
   std::vector <std::string> tags;
   split (tags, get ("tags"), ',');
 
@@ -1324,19 +1424,19 @@ float Task::urgency_c () const
 
 /* 
   // Very useful for debugging urgency problems.
-  std::cout << "# Urgency for " << id << ":\n"
-          << "#     pri " << (urgency_priority ()    * urgencyPriorityCoefficient)
-          << "#     pro " << (urgency_project ()     * urgencyProjectCoefficient)
-          << "#     act " << (urgency_active ()      * urgencyActiveCoefficient)
-          << "#     sch " << (urgency_scheduled ()   * urgencyScheduledCoefficient)
-          << "#     wai " << (urgency_waiting ()     * urgencyWaitingCoefficient)
-          << "#     blk " << (urgency_blocked ()     * urgencyBlockedCoefficient)
-          << "#     ann " << (urgency_annotations () * urgencyAnnotationsCoefficient)
-          << "#     tag " << (urgency_tags ()        * urgencyTagsCoefficient)
-          << "#     nex " << (urgency_next ()        * urgencyNextCoefficient)
-          << "#     due " << (urgency_due ()         * urgencyDueCoefficient)
-          << "#     bkg " << (urgency_blocking ()    * urgencyBlockingCoefficient)
-          << "#     age " << (urgency_age ()         * urgencyAgeCoefficient);
+  std::cout << "# Urgency for " << get ("uuid") << ":\n"
+          << "#     pri " << (urgency_priority ()    * urgencyPriorityCoefficient)    << "\n"
+          << "#     pro " << (urgency_project ()     * urgencyProjectCoefficient)     << "\n"
+          << "#     act " << (urgency_active ()      * urgencyActiveCoefficient)      << "\n"
+          << "#     sch " << (urgency_scheduled ()   * urgencyScheduledCoefficient)   << "\n"
+          << "#     wai " << (urgency_waiting ()     * urgencyWaitingCoefficient)     << "\n"
+          << "#     blk " << (urgency_blocked ()     * urgencyBlockedCoefficient)     << "\n"
+          << "#     ann " << (urgency_annotations () * urgencyAnnotationsCoefficient) << "\n"
+          << "#     tag " << (urgency_tags ()        * urgencyTagsCoefficient)        << "\n"
+          << "#     nex " << (urgency_next ()        * urgencyNextCoefficient)        << "\n"
+          << "#     due " << (urgency_due ()         * urgencyDueCoefficient)         << "\n"
+          << "#     bkg " << (urgency_blocking ()    * urgencyBlockingCoefficient)    << "\n"
+          << "#     age " << (urgency_age ()         * urgencyAgeCoefficient)         << "\n";
 */
 
   // Tag- and project-specific coefficients.
@@ -1458,12 +1558,9 @@ float Task::urgency_blocked () const
 ////////////////////////////////////////////////////////////////////////////////
 float Task::urgency_annotations () const
 {
-  std::map <std::string, std::string> annos;
-  getAnnotations (annos);
-
-       if (annos.size () >= 3) return 1.0;
-  else if (annos.size () == 2) return 0.9;
-  else if (annos.size () == 1) return 0.8;
+       if (annotation_count >= 3) return 1.0;
+  else if (annotation_count == 2) return 0.9;
+  else if (annotation_count == 1) return 0.8;
 
   return 0.0;
 }
@@ -1498,7 +1595,7 @@ float Task::urgency_due () const
     Date due (get_date ("due"));
     int days_overdue = (now - due) / 86400;
 
-         if (days_overdue >=  7)  return 1.0;
+         if (days_overdue >=  7)  return 1.0;  // 7 days ago
     else if (days_overdue >=  6)  return 0.96;
     else if (days_overdue >=  5)  return 0.92;
     else if (days_overdue >=  4)  return 0.88;
@@ -1519,7 +1616,7 @@ float Task::urgency_due () const
     else if (days_overdue >= -11) return 0.28;
     else if (days_overdue >= -12) return 0.24;
     else if (days_overdue >= -13) return 0.20;
-    else                          return 0.16;
+    else                          return 0.16; // two weeks from now
   }
 
   return 0.0;
