@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 // taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2012, Paul Beckingham, Federico Hernandez.
+// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -117,7 +117,9 @@ int CmdAnnotate::execute (std::string& output)
     else
     {
       std::cout << STRING_CMD_ANNO_NO << "\n";
-      rc  = 1;
+      rc = 1;
+      if (_permission_quit)
+        break;
     }
   }
 
