@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 // taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2012, Paul Beckingham, Federico Hernandez.
+// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -99,7 +99,6 @@ int CmdDone::execute (std::string& output)
         ++count;
         feedback_affected (STRING_CMD_DONE_TASK, *task);
         feedback_unblocked (*task);
-        context.tdb2.modify (*task);
         if (!nagged)
           nagged = nag (*task);
         dependencyChainOnComplete (*task);
@@ -109,7 +108,9 @@ int CmdDone::execute (std::string& output)
       else
       {
         std::cout << STRING_CMD_DONE_NO << "\n";
-        rc  = 1;
+        rc = 1;
+        if (_permission_quit)
+          break;
       }
     }
     else
