@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 // taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2012, Paul Beckingham, Federico Hernandez.
+// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -50,7 +50,7 @@ CmdEdit::CmdEdit ()
   _usage       = "task <filter> edit";
   _description = STRING_CMD_EDIT_USAGE;
   _read_only   = false;
-  _displays_id = true;
+  _displays_id = false;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -210,9 +210,7 @@ std::string CmdEdit::formatTask (Task task, const std::string& dateformat)
          << "  Until:             " << formatDate (task, "until", dateformat)           << "\n"
          << "  Recur:             " << task.get ("recur")                               << "\n"
          << "  Wait until:        " << formatDate (task, "wait", dateformat)            << "\n"
-         << "  Parent:            " << task.get ("parent")                              << "\n"
-         << "  Foreground color:  " << task.get ("fg")                                  << "\n"
-         << "  Background color:  " << task.get ("bg")                                  << "\n";
+         << "  Parent:            " << task.get ("parent")                              << "\n";
 
   if (verbose)
     before << "# " << STRING_EDIT_HEADER_13 << "\n"
@@ -613,38 +611,6 @@ void CmdEdit::parseTask (Task& task, const std::string& after, const std::string
     }
   }
 
-  // fg
-  value = findValue (after, "\n  Foreground color:");
-  if (value != task.get ("fg"))
-  {
-    if (value != "")
-    {
-      context.footnote (STRING_EDIT_FG_MOD);
-      task.set ("fg", value);
-    }
-    else
-    {
-      context.footnote (STRING_EDIT_FG_DEL);
-      task.remove ("fg");
-    }
-  }
-
-  // bg
-  value = findValue (after, "\n  Background color:");
-  if (value != task.get ("bg"))
-  {
-    if (value != "")
-    {
-      context.footnote (STRING_EDIT_BG_MOD);
-      task.set ("bg", value);
-    }
-    else
-    {
-      context.footnote (STRING_EDIT_BG_DEL);
-      task.remove ("bg");
-    }
-  }
-
   // Annotations
   std::map <std::string, std::string> annotations;
   std::string::size_type found = 0;
@@ -719,7 +685,8 @@ void CmdEdit::parseTask (Task& task, const std::string& after, const std::string
     if (type != "")
     {
       std::string value = findValue (after, "\n  UDA " + col->first + ":");
-      if (task.get (col->first) != value)
+      if ((task.get (col->first) != value) && (type != "date" ||
+           (task.get (col->first) != Date(value, dateformat).toEpochString ())))
       {
         if (value != "")
         {
@@ -804,6 +771,7 @@ bool CmdEdit::editFile (Task& task)
 
   // Format the contents, T -> text, write to a file.
   std::string before = formatTask (task, dateformat);
+  std::string before_orig = before;
   File::write (file.str (), before);
 
   // Determine correct editor: .taskrc:editor > $VISUAL > $EDITOR > vi
@@ -834,7 +802,7 @@ ARE_THESE_REALLY_HARMFUL:
 
   // Update task based on what can be parsed back out of the file, but only
   // if changes were made.
-  if (before != after)
+  if (before_orig != after)
   {
     std::cout << STRING_EDIT_CHANGES << "\n";
     std::string problem = "";
@@ -845,7 +813,7 @@ ARE_THESE_REALLY_HARMFUL:
       parseTask (task, after, dateformat);
     }
 
-    catch (std::string& e)
+    catch (const std::string& e)
     {
       problem = e;
       oops = true;
