@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 // taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2012, Paul Beckingham, Federico Hernandez.
+// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -38,6 +38,8 @@
 
 extern Context context;
 
+std::string zshColonReplacement = ",";
+
 ////////////////////////////////////////////////////////////////////////////////
 CmdIDs::CmdIDs ()
 {
@@ -66,6 +68,8 @@ int CmdIDs::execute (std::string& output)
 
   std::sort (ids.begin (), ids.end ());
   output = compressIds (ids) + "\n";
+  
+  context.headers.clear ();
   return 0;
 }
 
@@ -98,6 +102,8 @@ int CmdCompletionIds::execute (std::string& output)
   std::sort (ids.begin (), ids.end ());
   join (output, "\n", ids);
   output += "\n";
+
+  context.headers.clear ();
   return 0;
 }
 
@@ -127,10 +133,12 @@ int CmdZshCompletionIds::execute (std::string& output)
         task->getStatus () != Task::completed)
       out << task->id
           << ":"
-          << task->get ("description")
+          << str_replace(task->get ("description"), ":", zshColonReplacement)
           << "\n";
 
   output = out.str ();
+
+  context.headers.clear ();
   return 0;
 }
 
@@ -161,6 +169,8 @@ int CmdUUIDs::execute (std::string& output)
   std::sort (uuids.begin (), uuids.end ());
   join (output, ",", uuids);
   output += "\n";
+
+  context.headers.clear ();
   return 0;
 }
 
@@ -191,6 +201,8 @@ int CmdCompletionUuids::execute (std::string& output)
   std::sort (uuids.begin (), uuids.end ());
   join (output, "\n", uuids);
   output += "\n";
+
+  context.headers.clear ();
   return 0;
 }
 
@@ -218,10 +230,12 @@ int CmdZshCompletionUuids::execute (std::string& output)
   for (task = filtered.begin (); task != filtered.end (); ++task)
     out << task->get ("uuid")
         << ":"
-        << task->get ("description")
+        << str_replace (task->get ("description"), ":", zshColonReplacement)
         << "\n";
 
   output = out.str ();
+
+  context.headers.clear ();
   return 0;
 }
 
