@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 // taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2012, Paul Beckingham, Federico Hernandez.
+// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -300,29 +300,24 @@ int CmdInfo::execute (std::string& output)
 
     view.set (row, 1, entry + " (" + age + ")");
 
-    // fg TODO deprecated 2.0
-    std::string color = task->get ("fg");
-    if (color != "")
-    {
-      row = view.addRow ();
-      view.set (row, 0, STRING_COLUMN_LABEL_FG);
-      view.set (row, 1, color);
-    }
-
-    // bg TODO deprecated 2.0
-    color = task->get ("bg");
-    if (color != "")
-    {
-      row = view.addRow ();
-      view.set (row, 0, STRING_COLUMN_LABEL_BG);
-      view.set (row, 1, color);
-    }
-
     // Task::urgency
     row = view.addRow ();
     view.set (row, 0, STRING_COLUMN_LABEL_URGENCY);
     view.set (row, 1, trimLeft (format (task->urgency (), 4, 4)));
 
+    // modified
+    if (task->has ("modified"))
+    {
+      row = view.addRow ();
+      view.set (row, 0, STRING_CMD_INFO_MODIFIED);
+
+      Date mod (task->get_date ("modified"));
+
+      std::string age = Duration (now - mod).format ();
+      view.set (row, 1, Date (task->get_date ("modified")).toString (dateformat) +
+                              " (" + age + ")");
+    }
+
     // Show any UDAs
     std::vector <std::string> all = task->all ();
     std::vector <std::string>::iterator att;
@@ -387,6 +382,7 @@ int CmdInfo::execute (std::string& output)
       std::string current;
       unsigned int i = 0;
       long total_time = 0;
+      long last_timestamp = 0;
       while (i < undo.size ())
       {
         when = undo[i++];
@@ -408,7 +404,7 @@ int CmdInfo::execute (std::string& output)
 
             Task before (previous.substr (4));
             Task after (current.substr (4));
-            journal.set (row, 1, taskInfoDifferences (before, after, dateformat));
+            journal.set (row, 1, taskInfoDifferences (before, after, dateformat, last_timestamp, timestamp.toEpoch()));
 
             // calculate the total active time
             if (before.get ("start") == ""
