@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 // taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2012, Paul Beckingham, Federico Hernandez.
+// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -97,7 +97,7 @@ int CmdMerge::execute (std::string& output)
     {
         context.tdb2.merge (file);
     }
-    catch (std::string& e) {
+    catch (const std::string& e) {
         if (e == STRING_TDB2_UP_TO_DATE)
         {
             output += e + "\n";
