@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 // taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2012, Paul Beckingham, Federico Hernandez.
+// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -95,9 +95,15 @@ int CmdModify::execute (std::string& output)
         throw std::string (STRING_CMD_MODIFY_REC_ALWAYS);
 
       // Delete the specified task.
-      std::string question = format (STRING_CMD_MODIFY_CONFIRM,
-                                     task->id,
-                                     task->get ("description"));
+      std::string question;
+      if (task->id != 0)
+        question = format (STRING_CMD_MODIFY_CONFIRM,
+                           task->id,
+                           task->get ("description"));
+      else
+        question = format (STRING_CMD_MODIFY_CONFIRM,
+                           task->get ("uuid"),
+                           task->get ("description"));
 
       if (permission (*task, taskDifferences (before, *task) + question, filtered.size ()))
       {
@@ -160,7 +166,9 @@ int CmdModify::execute (std::string& output)
       else
       {
         std::cout << STRING_CMD_MODIFY_NO << "\n";
-        rc  = 1;
+        rc = 1;
+        if (_permission_quit)
+          break;
       }
     }
   }
