@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 // taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2012, Paul Beckingham, Federico Hernandez.
+// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -60,7 +60,7 @@ int CmdShow::execute (std::string& output)
   // Obtain the arguments from the description.  That way, things like '--'
   // have already been handled.
   std::vector <std::string> words = context.a3.extract_words ();
-  if (words.size () > 2)
+  if (words.size () > 1)
     throw std::string (STRING_CMD_SHOW_ARGS);
 
   int width = context.getWidth ();
@@ -173,6 +173,7 @@ int CmdShow::execute (std::string& output)
     " monthsperline"
     " nag"
     " patterns"
+    " print.empty.columns"
     " pull.default.uri"
     " push.default.uri"
     " recurrence.indicator"
@@ -229,6 +230,7 @@ int CmdShow::execute (std::string& output)
       if (i->substr (0, 14) != "color.keyword."        &&
           i->substr (0, 14) != "color.project."        &&
           i->substr (0, 10) != "color.tag."            &&
+          i->substr (0, 10) != "color.uda."            &&
           i->substr (0,  8) != "holiday."              &&
           i->substr (0,  7) != "report."               &&
           i->substr (0,  6) != "alias."                &&
@@ -264,6 +266,9 @@ int CmdShow::execute (std::string& output)
   Color error ("bold white on red");
   Color warning ("black on yellow");
 
+  bool issue_error = false;
+  bool issue_warning = false;
+
   std::string section;
 
   // Look for the first plausible argument which could be a pattern 
@@ -273,17 +278,24 @@ int CmdShow::execute (std::string& output)
   if (section == "all")
     section = "";
 
+  std::string::size_type loc;
   for (i = all.begin (); i != all.end (); ++i)
   {
-    std::string::size_type loc = i->find (section, 0);
+    loc = i->find (section, 0);
     if (loc != std::string::npos)
     {
       // Look for unrecognized.
       Color color;
       if (std::find (unrecognized.begin (), unrecognized.end (), *i) != unrecognized.end ())
+      {
+        issue_error = true;
         color = error;
+      }
       else if (std::find (default_values.begin (), default_values.end (), *i) != default_values.end ())
+      {
+        issue_warning = true;
         color = warning;
+      }
 
       std::string value = context.config.get (*i);
       // hide sensible information
@@ -307,7 +319,7 @@ int CmdShow::execute (std::string& output)
       << (view.rows () == 0 ? STRING_CMD_SHOW_NONE : "")
       << (view.rows () == 0 ? "\n\n" : "\n");
 
-  if (default_values.size ())
+  if (issue_warning)
   {
     out << STRING_CMD_SHOW_DIFFER;
 
@@ -318,7 +330,7 @@ int CmdShow::execute (std::string& output)
   }
 
   // Display the unrecognized variables.
-  if (unrecognized.size ())
+  if (issue_error)
   {
     out << STRING_CMD_SHOW_UNREC << "\n";
 
@@ -326,7 +338,7 @@ int CmdShow::execute (std::string& output)
       out << "  " << *i << "\n";
 
     if (context.color ())
-      out << "\n  " << format (STRING_CMD_SHOW_DIFFER_COLOR, error.colorize ("color"));
+      out << "\n" << format (STRING_CMD_SHOW_DIFFER_COLOR, error.colorize ("color"));
 
     out << "\n\n";
   }
@@ -339,46 +351,6 @@ int CmdShow::execute (std::string& output)
   // TODO Check for referenced but missing string files.
   // TODO Check for referenced but missing tips files.
 
-  // Check for referenced but missing hook scripts.
-#ifdef HAVE_LIBLUA
-  std::vector <std::string> missing_scripts;
-  for (i = all.begin (); i != all.end (); ++i)
-  {
-    if (i->substr (0, 5) == "hook.")
-    {
-      std::string value = context.config.get (*i);
-      Nibbler n (value);
-
-      // <path>:<function> [, ...]
-      while (!n.depleted ())
-      {
-        std::string file;
-        std::string function;
-        if (n.getUntil (':', file) &&
-            n.skip (':')           &&
-            n.getUntil (',', function))
-        {
-          Path script (file);
-          if (!script.exists () || !script.readable ())
-            missing_scripts.push_back (file);
-
-          (void) n.skip (',');
-        }
-      }
-    }
-  }
-
-  if (missing_scripts.size ())
-  {
-    out << STRING_CMD_SHOW_HOOKS << "\n";
-
-    for (i = missing_scripts.begin (); i != missing_scripts.end (); ++i)
-      out << "  " << *i << "\n";
-
-    out << "\n";
-  }
-#endif
-
   // Check for bad values in rc.calendar.details.
   std::string calendardetails = context.config.get ("calendar.details");
   if (calendardetails != "full"   &&
@@ -428,3 +400,33 @@ int CmdShow::execute (std::string& output)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
+CmdShowRaw::CmdShowRaw ()
+{
+  _keyword     = "_show";
+  _usage       = "task          _show";
+  _description = STRING_CMD_SHOWRAW;
+  _read_only   = true;
+  _displays_id = false;
+}
+
+////////////////////////////////////////////////////////////////////////////////
+int CmdShowRaw::execute (std::string& output)
+{
+  // Get all the settings.
+  std::vector <std::string> all;
+  context.config.all (all);
+
+  // Sort alphabetically by name.
+  std::sort (all.begin (), all.end ());
+
+  // Display them all.
+  std::vector <std::string>::iterator i;
+  std::stringstream out;
+  for (i = all.begin (); i != all.end (); ++i)
+    out << *i << '=' << context.config.get (*i) << "\n";
+
+  output = out.str ();
+  return 0;
+}
+
+////////////////////////////////////////////////////////////////////////////////
