@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 // taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2012, Paul Beckingham, Federico Hernandez.
+// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -41,6 +41,7 @@
 #include <main.h>
 
 #include <CmdAdd.h>
+#include <CmdAliases.h>
 #include <CmdAnnotate.h>
 #include <CmdAppend.h>
 #include <CmdBurndown.h>
@@ -79,7 +80,7 @@
 #include <CmdShell.h>
 #include <CmdShow.h>
 #include <CmdStart.h>
-#include <CmdStatistics.h>
+#include <CmdStats.h>
 #include <CmdStop.h>
 #include <CmdSummary.h>
 //#include <CmdSynch.h>
@@ -111,6 +112,7 @@ void Command::factory (std::map <std::string, Command*>& all)
   c = new CmdCalendar ();           all[c->keyword ()] = c;
   c = new CmdColor ();              all[c->keyword ()] = c;
   c = new CmdColumns ();            all[c->keyword ()] = c;
+  c = new CmdCompletionAliases ();  all[c->keyword ()] = c;
   c = new CmdCompletionColumns ();  all[c->keyword ()] = c;
   c = new CmdCompletionCommands (); all[c->keyword ()] = c;
   c = new CmdCompletionConfig ();   all[c->keyword ()] = c;
@@ -152,8 +154,9 @@ void Command::factory (std::map <std::string, Command*>& all)
   c = new CmdReports ();            all[c->keyword ()] = c;
   c = new CmdShell ();              all[c->keyword ()] = c;
   c = new CmdShow ();               all[c->keyword ()] = c;
+  c = new CmdShowRaw ();            all[c->keyword ()] = c;
   c = new CmdStart ();              all[c->keyword ()] = c;
-  c = new CmdStatistics ();         all[c->keyword ()] = c;
+  c = new CmdStats ();              all[c->keyword ()] = c;
   c = new CmdStop ();               all[c->keyword ()] = c;
   c = new CmdSummary ();            all[c->keyword ()] = c;
 //  c = new CmdSynch ();              all[c->keyword ()] = c;
@@ -210,6 +213,7 @@ Command::Command ()
 , _needs_confirm (false)
 , _permission_quit (false)
 , _permission_all (false)
+, _first_iteration (true)
 {
 }
 
@@ -223,6 +227,7 @@ Command::Command (const Command& other)
   _needs_confirm   = other._needs_confirm;
   _permission_quit = other._permission_quit;
   _permission_all  = other._permission_all;
+  _first_iteration = other._first_iteration;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -237,6 +242,7 @@ Command& Command::operator= (const Command& other)
     _needs_confirm   = other._needs_confirm;
     _permission_quit = other._permission_quit;
     _permission_all  = other._permission_all;
+    _first_iteration = other._first_iteration;
   }
 
   return *this;
@@ -418,7 +424,10 @@ void Command::modify_task_description_replace (Task& task, const A3& arguments)
   modify_task (task, arguments, description);
 
   if (description.length ())
-   task.set ("description", description);
+  {
+    _needs_confirm = true;
+    task.set ("description", description);
+  }
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -718,10 +727,12 @@ bool Command::permission (
   // 1 < Quantity < bulk modifications have optional confirmation, in the (y/n/a/q)
   // style.
   if (quantity < bulk && (!_needs_confirm || !confirmation))
-     return true;
+    return true;
 
+  if (context.verbose ("blank") && !_first_iteration)
+    std::cout << "\n";
   int answer = confirm4 (question);
-  std::cout << "\n";       // #499
+  _first_iteration = false;
   switch (answer)
   {
   case 1:                           return true;     // yes
