@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 // taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2012, Paul Beckingham, Federico Hernandez.
+// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -64,27 +64,28 @@
 //   2. Modify all the strings below.
 //        i.e. change "Unknown error." to "Unbekannter Fehler.".
 //
-//   3. Add your new translation to the task.git/src/i18n.h file by changing:
+//   3. Add your new translation to the task.git/src/i18n.h file, if necessary,
+//      by inserting:
 //
-//        #if PACKAGE_LANGUAGE == LANGUAGE_EN_US
-//        #include <en-US.h>
-//        #endif
-//
-//      to:
-//
-//        #if PACKAGE_LANGUAGE == LANGUAGE_EN_US
-//        #include <en-US.h>
 //        #elif PACKAGE_LANGUAGE == LANGUAGE_DE_DE
 //        #include <de-DE.h>
-//        #endif
 //
-//   4. Build your localized Taskwarrior with these commands:
+//   4. Add your new language to task.git/CMakeLists.txt, making sure that
+//      number is unique:
+//
+//        set (LANGUAGE_DE_DE 3)
+//
+//   5. Add your new language to task.git/cmake.h.in:
+//
+//        #define LANGUAGE_DE_DE ${LANGUAGE_DE_DE}                                        
+//
+//   6. Build your localized Taskwarrior with these commands:
 //
 //      cd task.git
-//      cmake -D PACKAGE_LANGUAGE=LANGUAGE_DE_DE .
+//      cmake -D LANGUAGE=3 .
 //      make
 //
-//   5. Submit your translation to support@taskwarrior.org, where it will be
+//   7. Submit your translation to support@taskwarrior.org, where it will be
 //      shared with others.
 //
 ////////////////////////////////////////////////////////////////////////////////
@@ -104,7 +105,7 @@
 
 // A3
 #define STRING_A3_ALTERNATE_RC       "Using alternate .taskrc file {1}"
-#define STRING_A3_ALTERNATE_DATA     "Using alternate date.location {1}"
+#define STRING_A3_ALTERNATE_DATA     "Using alternate data.location {1}"
 #define STRING_A3_OVERRIDE_RC        "Configuration override rc.{1}:{2}"
 #define STRING_A3_OVERRIDE_PROBLEM   "Problem with override: {1}"
 #define STRING_A3_UNKNOWN_ATTMOD     "Error: unrecognized attribute modifier '{1}'."
@@ -117,15 +118,6 @@
 #define STRING_A3_RANGE_INVERTED     "Inverted range 'high-low' instead of 'low-high'"
 #define STRING_A3_UUID_AFTER_COMMA   "Unrecognized UUID after comma."
 
-// API
-#define STRING_API_EXITING           "Exiting."
-#define STRING_API_NOFUNC            "The Lua function '{1}' was not found."
-#define STRING_API_ERROR_CALLING     "Error calling '{1}' - {2}."
-#define STRING_API_ERROR_FAIL        "Error: '{1}' did not return a success indicator."
-#define STRING_API_ERROR_NORET       "Error: '{1}' did not return a message or nil."
-#define STRING_API_WARNING           "Warning: {1}"
-#define STRING_API_ERROR             "Error: {1}"
-
 // Color
 #define STRING_COLOR_UNRECOGNIZED    "The color '{1}' is not recognized."
 
@@ -141,6 +133,7 @@
 #define STRING_COLUMN_LABEL_ENTERED  "Entered"
 #define STRING_COLUMN_LABEL_COUNT    "Count"
 #define STRING_COLUMN_LABEL_COMPLETE "Completed"
+#define STRING_COLUMN_LABEL_MOD      "Modified"
 #define STRING_COLUMN_LABEL_ADDED    "Added"
 #define STRING_COLUMN_LABEL_AGE      "Age"
 #define STRING_COLUMN_LABEL_ID       "ID"
@@ -176,8 +169,6 @@
 #define STRING_COLUMN_LABEL_MASK     "Mask"
 #define STRING_COLUMN_LABEL_MASK_IDX "Mask Index"
 #define STRING_COLUMN_LABEL_PARENT   "Parent task"
-#define STRING_COLUMN_LABEL_FG       "Foreground color"
-#define STRING_COLUMN_LABEL_BG       "Background color"
 #define STRING_COLUMN_LABEL_DATE     "Date"
 #define STRING_COLUMN_LABEL_COLUMN   "Columns"
 #define STRING_COLUMN_LABEL_STYLES   "Supported Formats"
@@ -191,7 +182,7 @@
 #define STRING_COLUMN_LABEL_ORPHAN   "Orphan UDA"
 
 // Column Examples
-#define STRING_COLUMN_EXAMPLES_TAGS  "home @chore"
+#define STRING_COLUMN_EXAMPLES_TAGS  "home @chore next"
 #define STRING_COLUMN_EXAMPLES_PROJ  "home.garden"
 #define STRING_COLUMN_EXAMPLES_PAR   "home"
 #define STRING_COLUMN_EXAMPLES_IND   "  home.garden"
@@ -209,8 +200,7 @@
 #define STRING_CMD_VERSION_DOCS      "Documentation for taskwarrior can be found using 'man task', 'man taskrc', 'man task-tutorial', 'man task-color', 'man task-sync', 'man task-faq' or at http://taskwarrior.org"
 #define STRING_CMD_VERSION_BUILT     "{1} {2} built for "
 #define STRING_CMD_VERSION_UNKNOWN   "unknown"
-#define STRING_CMD_VERSION_COPY      "Copyright (C) 2006 - 2012 P. Beckingham, F. Hernandez."
-#define STRING_CMD_VERSION_COPY2     "Portions of this software Copyright (C) 1994 – 2008 Lua.org, PUC-Rio."
+#define STRING_CMD_VERSION_COPY      "Copyright (C) 2006 - 2013 P. Beckingham, F. Hernandez."
 #define STRING_CMD_LOGO_USAGE        "Displays the Taskwarrior logo"
 #define STRING_CMD_LOGO_COLOR_REQ    "The logo command requires that color support is enabled."
 #define STRING_CMD_EXEC_USAGE        "Executes external commands and scripts"
@@ -238,6 +228,7 @@
 #define STRING_CMD_INFO_UNTIL        "Until"
 #define STRING_CMD_INFO_MODIFICATION "Modification"
 #define STRING_CMD_INFO_TOTAL_ACTIVE "Total active time"
+#define STRING_CMD_INFO_MODIFIED     "Last modified"
 #define STRING_CMD_UNDO_USAGE        "Reverts the most recent change to a task"
 #define STRING_CMD_UNDO_MODS         "The undo command does not allow further task modification."
 #define STRING_CMD_STATS_USAGE       "Shows task database statistics"
@@ -260,6 +251,8 @@
 #define STRING_CMD_STATS_DESC_LEN    "Average desc length"
 #define STRING_CMD_STATS_CHARS       "{1} characters"
 #define STRING_CMD_STATS_LAST_SYNCH  "Last server synchronization"
+#define STRING_CMD_STATS_BLOCKED     "Blocked tasks"
+#define STRING_CMD_STATS_BLOCKING    "Blocking tasks"
 #define STRING_CMD_REPORTS_USAGE     "Lists all supported reports"
 #define STRING_CMD_REPORTS_REPORT    "Report"
 #define STRING_CMD_REPORTS_DESC      "Description"
@@ -385,6 +378,7 @@
 #define STRING_CMD_COLUMNS_USAGE     "All supported columns and formatting styles"
 #define STRING_CMD_COLUMNS_NOTE      "* Means default format, and therefore optional.  For example, 'due' and 'due.formatted' are equivalent."
 #define STRING_CMD_COLUMNS_USAGE2    "Displays only a list of supported columns"
+#define STRING_CMD_COLUMNS_ARGS      "You can only specify one search string."
 
 #define STRING_CMD_DENO_USAGE        "Deletes an annotation"
 #define STRING_CMD_DENO_WORDS        "An annotation pattern must be provided."
@@ -392,6 +386,7 @@
 #define STRING_CMD_DENO_CONFIRM      "Denotate task {1} '{2}'?"
 #define STRING_CMD_DENO_FOUND        "Found annotation '{1}' and deleted it."
 #define STRING_CMD_DENO_NOMATCH      "Did not find any matching annotation to be deleted for '{1}'."
+#define STRING_CMD_DENO_NO           "Task not denotated."
 #define STRING_CMD_DENO_1            "Denotated {1} task."
 #define STRING_CMD_DENO_N            "Denotated {1} tasks."
 
@@ -414,7 +409,6 @@
 #define STRING_CMD_DIAG_COMPILER     "Compiler"
 #define STRING_CMD_DIAG_VERSION      "Version"
 #define STRING_CMD_DIAG_CAPS         "Caps"
-#define STRING_CMD_DIAG_LIBRARIES    "Libraries"
 #define STRING_CMD_DIAG_FEATURES     "Build Features"
 #define STRING_CMD_DIAG_BUILT        "Built"
 #define STRING_CMD_DIAG_COMMIT       "Commit"
@@ -444,6 +438,7 @@
 #define STRING_CMD_PULL_NOT_DIR      "The uri '{1}' is not a directory.  Did you forget a trailing '/'?"
 #define STRING_CMD_HCOMMANDS_USAGE   "Generates a list of all commands, for autocompletion purposes"
 #define STRING_CMD_ZSHCOMMANDS_USAGE "Generates a list of all commands, for zsh autocompletion purposes"
+#define STRING_CMD_ALIASES_USAGE     "Generates a list of all aliases, for autocompletion purposes"
 #define STRING_CMD_INSTALL_USAGE     "Installs extensions and external scripts"
 
 #define STRING_CMD_MODIFY_USAGE1     "Modifies the existing task with provided arguments."
@@ -466,7 +461,7 @@
 #define STRING_CMD_COLOR_EXPLANATION "Use this command to see how colors are displayed by your terminal."
 #define STRING_CMD_COLOR_16          "16-color usage (supports underline, bold text, bright background):"
 #define STRING_CMD_COLOR_256         "256-color usage (supports underline):"
-#define STRING_CMD_COLOR_YOURS       "Your sample:"                                                        << "\n"
+#define STRING_CMD_COLOR_YOURS       "Your sample:"
 #define STRING_CMD_COLOR_BASIC       "Basic colors"
 #define STRING_CMD_COLOR_EFFECTS     "Effects"
 #define STRING_CMD_COLOR_CUBE        "Color cube rgb"
@@ -545,6 +540,7 @@
 // Date
 #define STRING_DATE_INVALID_FORMAT   "'{1}' is not a valid date in the '{2}' format."
 #define STRING_DATE_BAD_WEEKSTART    "The 'weekstart' configuration variable may only contain 'Sunday' or 'Monday'."
+#define STRING_DATE_TOO_MUCH         "The date is too far into the future."
 
 #define STRING_DATE_JANUARY_LONG     "january"
 #define STRING_DATE_FEBRUARY_LONG    "february"
@@ -649,10 +645,6 @@
 #define STRING_EDIT_WAIT_DEL         "Wait date removed."
 #define STRING_EDIT_PARENT_MOD       "Parent UUID modified."
 #define STRING_EDIT_PARENT_DEL       "Parent UUID removed."
-#define STRING_EDIT_FG_MOD           "Foreground color modified."
-#define STRING_EDIT_FG_DEL           "Foreground color removed."
-#define STRING_EDIT_BG_MOD           "Background color modified."
-#define STRING_EDIT_BG_DEL           "Background color removed."
 #define STRING_EDIT_UDA_MOD          "UDA {1} modified."
 #define STRING_EDIT_UDA_DEL          "UDA {1} deleted."
 
@@ -689,6 +681,7 @@
 #define STRING_ASSUME_INFO           "No command specified - assuming 'information'."
 #define STRING_INFINITE_LOOP         "Terminated substitution because more than {1} changes were made - infinite loop protection."
 #define STRING_UDA_TYPE              "User defined attributes may only be of type 'string', 'date', 'duration' or 'numeric'."
+#define STRING_UDA_TYPE_MISSING      "uda.{1}.type not found. The UDA '{1}' must have a type specified."
 #define STRING_UDA_NUMERIC           "The value '{1}' is not a valid numeric value."
 #define STRING_UDA_COLLISION         "The UDA named '{1}' is the same as a core attribute, and is not permitted."
 #define STRING_INVALID_MOD           "The '{1}' attribute does not allow a value of '{2}'."
@@ -709,6 +702,7 @@
 #define STRING_FEEDBACK_ATT_SET      "{1} will be set to '{2}'."
 #define STRING_FEEDBACK_ATT_MOD      "{1} will be changed from '{2}' to '{3}'."
 #define STRING_FEEDBACK_ATT_DEL      "{1} deleted."
+#define STRING_FEEDBACK_ATT_DEL_DUR  "{1} deleted (duration: {2})."
 #define STRING_FEEDBACK_ATT_WAS_SET  "{1} set to '{2}'."
 #define STRING_FEEDBACK_ATT_WAS_MOD  "{1} changed from '{2}' to '{3}'."
 #define STRING_FEEDBACK_ANN_ADD      "Annotation of '{1}' added."
@@ -718,13 +712,13 @@
 #define STRING_FEEDBACK_WAS_NOP      "No changes made."
 #define STRING_FEEDBACK_TAG_NOCOLOR  "The 'nocolor' special tag will disable color rules for this task."
 #define STRING_FEEDBACK_TAG_NONAG    "The 'nonag' special tag will prevent nagging when this task is modified."
-#define STRING_FEEDBACK_TAG_NOCAL    "The 'nocal' special tag will keep this task off the calendar report."
+#define STRING_FEEDBACK_TAG_NOCAL    "The 'nocal' special tag will keep this task off the 'calendar' report."
 #define STRING_FEEDBACK_TAG_NEXT     "The 'next' special tag will boost the urgency of this task so it appears on the 'next' report."
 #define STRING_FEEDBACK_UNBLOCKED    "Unblocked {1} '{2}'."
 #define STRING_FEEDBACK_EXPIRED      "Task {1} '{2}' expired and was deleted."
 
 // File
-#define STRING_FILE_PERMS            "Task does not have the correct permissions for '{1}'."
+#define STRING_FILE_PERMS            "Taskwarrior does not have the correct permissions for '{1}'."
 
 // helpers
 #define STRING_HELPER_PROJECT_CHANGE "The project '{1}' has changed."
@@ -747,10 +741,6 @@
 // Legacy
 #define STRING_LEGACY_FEATURE        "Note: the '{1}' feature is deprecated."
 
-// Lua
-#define STRING_LUA_BAD_HOOK_DEF      "Malformed hook definition '{1}'."
-#define STRING_LUA_BAD_EVENT         "Unrecognized hook event '{1}'."
-
 // Record
 #define STRING_RECORD_EMPTY          "Empty record in input."
 #define STRING_RECORD_JUNK_AT_EOL    "Unrecognized characters at end of line."
@@ -770,6 +760,7 @@
 #define STRING_CMD_SHOW_LOC_EXIST    "Configuration error: data.location contains a directory name that doesn't exist, or is unreadable."
 #define STRING_CMD_SHOW_CONF_VAR     "Config Variable"
 #define STRING_CMD_SHOW_CONF_VALUE   "Value"
+#define STRING_CMD_SHOWRAW           "Shows all configuration settings in a machine-readable format"
 
 // Task
 #define STRING_TASK_NO_FF1           "Taskwarrior no longer supports file format 1, originally used between 27 November 2006 and 31 December 2007."
@@ -831,15 +822,18 @@
 #define STRING_TEXT_AMBIGUOUS        "Ambiguous {1} '{2}' - could be either of "
 
 // Transport
+#define STRING_TRANSPORT_NORUN       "Could not run '{1}'.  Is it installed, and available in $PATH?"
+#define STRING_TRANSPORT_NOFORK      "Could not run '{1}': {2}.  Are you out of system resources?"
 #define STRING_TRANSPORT_URI_NODIR   "The uri '{1}' does not appear to be a directory."
 #define STRING_TRANSPORT_CURL_URI    "When using the 'curl' protocol, the uri must contain a hostname."
 #define STRING_TRANSPORT_CURL_WILDCD "When using the 'curl' protocol, wildcards are not supported."
-#define STRING_TRANSPORT_CURL_NORUN  "Could not run curl.  Is it installed, and available in $PATH?"
 #define STRING_TRANSPORT_CURL_FAIL   "Curl failed, see output above."
 #define STRING_TRANSPORT_RSYNC_URI   "When using the 'rsync' protocol, the uri must contain a hostname."
-#define STRING_TRANSPORT_RSYNC_NORUN "Could not run rsync.  Is it installed, and available in $PATH?"
+#define STRING_TRANSPORT_RSYNC_FAIL  "rsync failed, see output above."
 #define STRING_TRANSPORT_SSH_URI     "When using the 'ssh' protocol, the uri must contain a hostname."
-#define STRING_TRANSPORT_SSH_NORUN   "Could not run ssh.  Is it installed, and available in $PATH?"
+#define STRING_TRANSPORT_SSH_FAIL    "ssh failed, see output above."
+#define STRING_TRANSPORT_SHELL_NOPATH "When using the 'sh+cp' protocol to copy multiple files, a path must be specified."
+#define STRING_TRANSPORT_SHELL_FAIL  "shell command failed, see output above."
 
 // Uri
 #define STRING_URI_QUOTES            "Could not parse uri '{1}', wrong usage of single quotes."
@@ -849,6 +843,9 @@
 #define STRING_UTF8_INVALID_CP_REP   "Invalid codepoint representation."
 #define STRING_UTF8_INVALID_CP       "Invalid Unicode codepoint."
 
+// View
+#define STRING_VIEW_TOO_SMALL        "The report has a minimum width of {1} and does not fit in the available width of {2}."
+
 // Usage text.  This is an exception, and contains \n characters and formatting.
 #define STRING_CMD_HELP_TEXT \
   "Documentation for Taskwarrior can be found using 'man task', 'man taskrc', 'man " \
