@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 // taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2012, Paul Beckingham, Federico Hernandez.
+// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -37,9 +37,7 @@ extern Context context;
 ////////////////////////////////////////////////////////////////////////////////
 void legacyAttributeCheck (const std::string& name)
 {
-  // Legacy checks.
-  if (name == "fg" || name == "bg")
-    context.footnote (format (STRING_LEGACY_FEATURE, name));
+  // 2013-07-25: Deprecated "fg" and "bg" removed.
 }
 
 ////////////////////////////////////////////////////////////////////////////////
