@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 // taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2012, Paul Beckingham, Federico Hernandez.
+// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -211,16 +211,22 @@ static void colorizeKeyword (Task& task, const std::string& rule, const Color& b
   }
 }
 
+////////////////////////////////////////////////////////////////////////////////
+static void colorizeUDA (Task& task, const std::string& rule, const Color& base, Color& c)
+{
+  if (task.has (rule.substr (10)))
+    c.blend (base);
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 static void colorizeDue (Task& task, const Color& base, Color& c)
 {
-  Task::status status = task.getStatus ();
-
-  if (task.has ("due")          &&
-      status != Task::completed &&
-      status != Task::deleted)
+  if (task.has ("due"))
   {
-    if (getDueState (task.get ("due")) == 1)
+    Task::status status = task.getStatus ();
+    if (status != Task::completed &&
+        status != Task::deleted   &&
+        getDueState (task.get ("due")) == 1)
       c.blend (base);
   }
 }
@@ -228,13 +234,12 @@ static void colorizeDue (Task& task, const Color& base, Color& c)
 ////////////////////////////////////////////////////////////////////////////////
 static void colorizeDueToday (Task& task, const Color& base, Color& c)
 {
-  Task::status status = task.getStatus ();
-
-  if (task.has ("due")          &&
-      status != Task::completed &&
-      status != Task::deleted)
+  if (task.has ("due"))
   {
-    if (getDueState (task.get ("due")) == 2)
+    Task::status status = task.getStatus ();
+    if (status != Task::completed &&
+        status != Task::deleted   &&
+        getDueState (task.get ("due")) == 2)
       c.blend (base);
   }
 }
@@ -242,13 +247,12 @@ static void colorizeDueToday (Task& task, const Color& base, Color& c)
 ////////////////////////////////////////////////////////////////////////////////
 static void colorizeOverdue (Task& task, const Color& base, Color& c)
 {
-  Task::status status = task.getStatus ();
-
-  if (task.has ("due")          &&
-      status != Task::completed &&
-      status != Task::deleted)
+  if (task.has ("due"))
   {
-    if (getDueState (task.get ("due")) == 3)
+    Task::status status = task.getStatus ();
+    if (status != Task::completed &&
+        status != Task::deleted   &&
+        getDueState (task.get ("due")) == 3)
       c.blend (base);
   }
 }
@@ -270,7 +274,7 @@ static void colorizeCompleted (Task& task, const Color& base, Color& c)
 ////////////////////////////////////////////////////////////////////////////////
 static void colorizeDeleted (Task& task, const Color& base, Color& c)
 {
-  if (task.getStatus () == Task::completed)
+  if (task.getStatus () == Task::deleted)
     c.blend (base);
 }
 
@@ -316,6 +320,7 @@ void autoColorize (Task& task, Color& c)
       else if (r->substr (0, 10) == "color.tag.")     colorizeTag          (task, *r, base, c);
       else if (r->substr (0, 14) == "color.project.") colorizeProject      (task, *r, base, c);
       else if (r->substr (0, 14) == "color.keyword.") colorizeKeyword      (task, *r, base, c);
+      else if (r->substr (0, 10) == "color.uda.")     colorizeUDA          (task, *r, base, c);
     }
   }
 }
