@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 // taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2012, Paul Beckingham, Federico Hernandez.
+// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -70,8 +70,8 @@ static inline unsigned round_up_to (unsigned n, unsigned target)
 bool confirm (const std::string& question)
 {
   std::vector <std::string> options;
-  options.push_back ("yes");
-  options.push_back ("no");
+  options.push_back (STRING_UTIL_CONFIRM_YES);
+  options.push_back (STRING_UTIL_CONFIRM_NO);
 
   std::string answer;
   std::vector <std::string> matches;
@@ -406,7 +406,7 @@ int execute(const std::string& executable, std::vector<std::string> arguments)
 
   // create command line before forking because the parent process also needs this for 
   // calling context.debug()
-  char shell[] = "bash";
+  char shell[] = "sh";
   char opt[]   = "-c";
 
   std::string cmdline = executable;
@@ -417,7 +417,7 @@ int execute(const std::string& executable, std::vector<std::string> arguments)
     cmdline += " " + (std::string)*it;
   }
 
-	context.debug ("Executing: " + std::string(shell) + " " + std::string(opt) + " " + cmdline);
+  context.debug ("Executing: " + std::string(shell) + " " + std::string(opt) + " " + cmdline);
 
   pid_t child_pid = fork();
 
@@ -425,9 +425,9 @@ int execute(const std::string& executable, std::vector<std::string> arguments)
   {
     // this is done by the child process
     char** argv = new char*[4];
-    argv[0] = shell;                  // bash
+    argv[0] = shell;                  // sh
     argv[1] = opt;                    // -c
-    argv[2] = (char*)cmdline.c_str();	// e.g. scp undo.data user@host:.task/
+    argv[2] = (char*)cmdline.c_str(); // e.g. scp undo.data user@host:.task/
     argv[3] = NULL;                   // required by execv
 
     int ret = execvp(shell, argv);
@@ -435,6 +435,10 @@ int execute(const std::string& executable, std::vector<std::string> arguments)
 
     exit(ret);
   }
+  else if (child_pid == -1)
+  {
+    return -1;
+  }
   else
   {
     // this is done by the parent process
@@ -445,7 +449,7 @@ int execute(const std::string& executable, std::vector<std::string> arguments)
     if (pid == -1)
       return -1;
     else
-      return child_status;
+      return WEXITSTATUS (child_status);
   }
 }
 
@@ -602,13 +606,41 @@ const std::string indentProject (
   // Count the delimiters in *i.
   std::string prefix = "";
   std::string::size_type pos = 0;
+  std::string::size_type lastpos = 0;
   while ((pos = project.find (delimiter, pos + 1)) != std::string::npos)
-    prefix += whitespace;
+  {
+    if (pos != project.size () - 1)
+    {
+      prefix += whitespace;
+      lastpos = pos;
+    }
+  }
 
-  return prefix + project;
+  std::string child = "";
+  if (lastpos == 0)
+    child = project;
+  else
+    child = project.substr (lastpos + 1);
+
+  return prefix + child;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
+const std::vector <std::string> extractParents (
+  const std::string& project,
+  const char& delimiter /* = '.' */)
+{
+  std::vector <std::string> vec;
+  std::string::size_type pos = 0;
+  std::string::size_type copyUntil = 0;
+  while ((copyUntil = project.find (delimiter, pos + 1)) != std::string::npos)
+  {
+    if (copyUntil != project.size () - 1)
+      vec.push_back (project.substr (0, copyUntil));
+    pos = copyUntil;
+  }
+  return vec;
+}
 
 ////////////////////////////////////////////////////////////////////////////////
 #ifndef HAVE_TIMEGM
@@ -628,5 +660,6 @@ time_t timegm (struct tm *tm)
   return ret;
 }
 #endif
+
 ////////////////////////////////////////////////////////////////////////////////
 
