@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 // taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2012, Paul Beckingham, Federico Hernandez.
+// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -84,6 +84,10 @@ const std::string indentProject (
   const std::string& whitespace = "  ",
   char delimiter = '.');
 
+const std::vector <std::string> extractParents (
+  const std::string&,
+  const char& delimiter = '.');
+
 #ifndef HAVE_TIMEGM
   time_t timegm (struct tm *tm);
 #endif
